@@ -102,7 +102,7 @@ class NnMixer:
                 losses_bellow_95th_percentile = loss_confidence_arr[k][loss_confidence_arr[k] < nf_pct]
                 if len(losses_bellow_95th_percentile) < 1:
                     losses_bellow_95th_percentile = loss_confidence_arr[k]
-                    
+
                 self.max_confidence_per_output[k] = max(losses_bellow_95th_percentile)
 
         return True
@@ -270,7 +270,10 @@ class NnMixer:
         :param model: a model object
         :return: None
         """
-
+        if 'cuda' in str(self.net.device):
+            torch.cuda.empty_cache()
+        self.optimizer.zero_grad()
+        self.optimizer = self.optimizer_class(self.net.parameters(), **self.optimizer_args)
         self.net = model
 
     def fit_data_source(self, ds):
@@ -328,7 +331,7 @@ class NnMixer:
 
             self.optimizer_class = Ranger
             if self.optimizer_args is None:
-                self.optimizer_args = {}
+                self.optimizer_args = {'lr': 0.0005}
 
             if 'beta1' in self.dynamic_parameters:
                 self.optimizer_args['betas'] = (self.dynamic_parameters['beta1'],0.999)
